//Bibliothek zum steuern der NeoPixel am Mikrocontroller
#include <Adafruit_NeoPixel.h>

//Bibliothek zum entprellen der Taster
#include <Bounce2.h>

//Taster 1 am GPIO13 angeschlossen
#define button1 13
//RGB Stripe 2 am GPIO16 angeschlossen
#define rgbStripe1 16

//Taster 2 am GPIO27 angeschlossen
#define button2 27

//Bounce2 Objekte initialisieren für die Taster
Bounce btn1 = Bounce();
Bounce btn2 = Bounce();

const int PUSH_INTERVAL = 25;

//Anzahl der NeoPixel pro Modul / Stripe
const int NUM_PIXEL = 16;

//Initialisieren der Adafruit_NeoPixel Objekte
//für jeden Stripe wird ein Objekt benötigt.
Adafruit_NeoPixel pixelStripe = Adafruit_NeoPixel(NUM_PIXEL, rgbStripe1, NEO_GRB + NEO_KHZ800);

//Wie oft die RGB Stripe blinken soll,
//dabei zählt jeweil einmal AN und einmal AUS als zwei Schritte.
//Möchtest du also das die RGB Stripes 10 mit pause aufleuchten so
//musst du den Wert mal zwei nehmen.
const int COUNT_BLINK = 5;
const int BLINK_PAUSE = 250;

void setup() {
  Serial.begin(115200);

  //Einrichten des ersten Tasters
  btn1.attach(button1, INPUT_PULLUP);
  btn1.interval(PUSH_INTERVAL);

  //Einrichten des zweiten Tasters
  btn2.attach(button2, INPUT_PULLUP);
  btn2.interval(PUSH_INTERVAL);

  //Beginn der kommunikation mit den RGB Stripes
  pixelStripe.begin();
}

/**
* Funktion um ein RGB Stripe zum blinken zu bringen.
* Die RGB Stripes sind jeweils hintereinander gekoppelt.
* Die erste RGB Stripe beginnt von 0 und endet bei 7,
* die zweite RGB Stripe beginnt bei 8 und ende bei 16.
**/
void blinkRgbStripe(int from, int to) {
  //Schleife von 0 bis Wert COUNT_BLINK
  for (int i = 0; i < COUNT_BLINK; i++) {
    //Wenn die Teilung der Schleifenvariable i durch 2 keinen Rest
    //ergibt dann...
    if (i % 2 == 0) {
      pixelStripe.fill((255, 255, 255), from, to);
    } else {
      pixelStripe.clear();
    }
    pixelStripe.show();
    //eine kleine Pause
    delay(BLINK_PAUSE);
  }
  //zum schluss löschen der Pixel
  pixelStripe.clear();
  pixelStripe.show();
}

void loop() {
  //aktualisieren der Bounce2 Objekte
  btn1.update();
  btn2.update();

  //Wenn die Taste betätigt wird, dann...
  if (btn1.fell()) {
    blinkRgbStripe(0, 7);
  }

  if (btn2.fell()) {
    blinkRgbStripe(8, 16);
  }
}